#==============================================================================#
# utilty functions:
#==============================================================================#

#------------------------------------------------------------------------------#
# file.name: return filedir part of /filedir/filename
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
file.name <- function(fullname) {
   isdir <- file.info(fullname)[,"isdir"];
   if (is.na(isdir)) return(NA);
   ifelse (isdir, "", basename(fullname));  
}

#------------------------------------------------------------------------------#
# file.dir: return filename part of /filedir/filename
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
file.dir <-function(fullname) {
   isdir <- file.info(fullname)[,"isdir"];
   if (is.na(isdir)) return(NA);
   ifelse (isdir, fullname, dirname(fullname));  
}

#------------------------------------------------------------------------------#
# validMsg: utility function for setValidity
# taken from package BioBase: tools.R
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
validMsg <- function(msg, result) {
   if (is.character(result)) {
      append(msg, result);
   } else {
      msg;
   }#if
}#validMsg

#------------------------------------------------------------------------------#
# pathFile: return file as /filedir/filename
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
pathFile <- function(filename=character(0), filedir=character(0)) {
   print("------pathFile------")

   ## for case that filename=/path/filename
   if (length(filename) != 0) {
      filename <- basename(filename);
   }#if

###test only###
   if (length(filename) == 0) {
      filename <- as.character("TESTNAME");
   }#if
###############

   if (dirname(filename) != ".") {
      filedir <- dirname(filename);
   }#if
#print(paste("filedir = ", filedir))

   ## set default directory
   if (filedir == "" || filedir == ".") {
      filedir <- as.character(getwd());
   }#if

   ## remove trailing "/"
   if (substr(filedir, nchar(filedir), nchar(filedir)) == "/") {
      filedir <- substr(filedir, 0, nchar(filedir)-1);
   }#if
#print(paste("filedir = ", filedir))

   ## set file to /fullpath/filename
   dirfile <- paste(filedir, "/", filename, sep="");
#print(paste("dirfile = ", dirfile))

   return(dirfile);
}#pathFile

#------------------------------------------------------------------------------#
# validPathFile: check if file is valid
# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
validPathFile <- function(dirfile) {
   print("------validPathFile------")

   if (length(dirfile) == 0 || !file.exists(dirfile)) {
      stop("missing file");
   }#if
#print(paste("dirfile = ",dirfile))

   filedir <- dirname(dirfile);
   if (!(is(filedir, "character") && file.exists(filedir))) {
      stop(paste(sQuote("filedir"), "is not a system directory"));
   }#if
#print(paste("filedir = ",filedir))

   return(dirfile);
}#validPathFile


#------------------------------------------------------------------------------#
